aboutsummaryrefslogtreecommitdiffstats
path: root/config/hypr/scripts/Kitty_themes.sh
diff options
context:
space:
mode:
authorJaKooLit <ejhay.games@gmail.com>2025-03-20 18:08:17 +0900
committerJaKooLit <ejhay.games@gmail.com>2025-03-20 18:08:17 +0900
commitc414b2b4bb3a5be82ce48c054b35803a04c8517e (patch)
treea55fe5f2c0907ad0ab379fe88325278ff0f3861e /config/hypr/scripts/Kitty_themes.sh
parentdffd296b92f06b1606f8d03137fbf235a39d261b (diff)
updated some scripts to reflect new images on swaync
Diffstat (limited to 'config/hypr/scripts/Kitty_themes.sh')
-rwxr-xr-xconfig/hypr/scripts/Kitty_themes.sh10
1 files changed, 8 insertions, 2 deletions
diff --git a/config/hypr/scripts/Kitty_themes.sh b/config/hypr/scripts/Kitty_themes.sh
index 471b7143..31c19a1d 100755
--- a/config/hypr/scripts/Kitty_themes.sh
+++ b/config/hypr/scripts/Kitty_themes.sh
@@ -9,12 +9,18 @@ kitty_config="$HOME/.config/kitty/kitty.conf"
iDIR="$HOME/.config/swaync/images"
rofi_theme="$HOME/.config/rofi/config-kitty-theme.rasi"
+# Check if the Kitty Themes directory exists
+if [ ! -d "$kitty_themes_DiR" ]; then
+ notify-send -i "$iDIR/error.png" "E-R-R-O-R" "Unable to locate Kitty Themes directory. Exiting....."
+ exit 1
+fi
+
# List the kitty-theme files from the themes directory
theme=$(ls "$kitty_themes_DiR"/*.conf | xargs -n 1 basename | sed 's/\.conf$//' | rofi -dmenu -config $rofi_theme)
# Check if the user selected a theme
if [ -z "$theme" ]; then
- echo "No theme selected, exiting..."
+ notify-send -u low -i "$iDIR/note.png" "No kitty theme" "selected. Exiting....."
exit 1
fi
send patches to the email below
@@ -9,12 +9,18 @@ kitty_config="$HOME/.config/kitty/kitty.conf"
# List the kitty-theme files from the themes directory
theme=$(ls "$kitty_themes_DiR"/*.conf | xargs -n 1 basename | sed 's/\.conf$//' | rofi -dmenu -config $rofi_theme)
-# Check if the user selected a theme
+# Check if no theme was selected, and exit if empty
if [ -z "$theme" ]; then
yukais@pinapelz.com
include the subject [PATCH repo_name]
pinapelz.com
homepage